@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.49 2011/10/08 14:08:26 peter Exp $
+ * Version    : $Id: ipv6calc.c,v 1.54 2011/11/26 16:07:23 peter Exp $
  * Copyright  : 2001-2011 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
@@ -152,9 +152,13 @@ void printversion_verbose(void) {
 
 #ifdef SUPPORT_GEOIP
 #ifdef SUPPORT_GEOIP_V6
+#if defined (SUPPORT_GEOIP_COUNTRY_CODE_BY_ADDR_V6) && defined (SUPPORT_GEOIP_COUNTRY_NAME_BY_ADDR_V6)
 	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 & IPv6 support\n");
 #else
-	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 support ONLY\n");
+	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 & IPv6 support (in compatibilty mode)\n");
+#endif
+#else
+	fprintf(stderr, "GeoIP support enabled, compiled with IPv4 support only\n");
 #endif
 #ifdef SUPPORT_GEOIP_LIB_VERSION
 	fprintf(stderr, "GeoIP dynamic library version (on this system): %s\n", GeoIP_lib_version());
@@ -221,6 +225,7 @@ int main(int argc, char *argv[]) {
 	int bit_start = 0, bit_end = 0, force_prefix = 0;
 	char *input1 = NULL, *input2 = NULL;
 	int inputc;
+	int inputtype_given = 0, outputtype_given = 0, action_given = 0;
 
 	/* new option style storage */	
 	uint32_t inputtype  = FORMAT_undefined;
@@ -671,6 +676,7 @@ int main(int argc, char *argv[]) {
 					fprintf(stderr, " Input option is unknown: %s\n", optarg);
 					exit(EXIT_FAILURE);
 				};
+				inputtype_given = 1;
 				break;	
 				
 			case 'O':	
@@ -689,6 +695,7 @@ int main(int argc, char *argv[]) {
 					fprintf(stderr, " Output option is unknown: %s\n", optarg);
 					exit(EXIT_FAILURE);
 				};
+				outputtype_given = 1;
 				break;	
 
 			case 'A':	
@@ -706,6 +713,7 @@ int main(int argc, char *argv[]) {
 					fprintf(stderr, " Action option is unknown: %s\n", optarg);
 					exit(EXIT_FAILURE);
 				};
+				action_given = 1;
 				break;
 				
 			default:
@@ -755,7 +763,7 @@ int main(int argc, char *argv[]) {
 		} else {
 			printversion();
 		};
-		exit(EXIT_FAILURE);
+		exit(EXIT_SUCCESS);
 	};
 
 	if (command == CMD_printoldoptions) {
@@ -778,46 +786,6 @@ int main(int argc, char *argv[]) {
 		};
 	};
 
-	/***** automatic action handling *****/
-	if ( action == ACTION_undefined ) {
-		/*
-		if ((formatoptions & FORMATOPTION_quiet) == 0) {
-			fprintf(stderr, "No action type specified, try autodetection...");
-		};
-		*/
-
-		if ( (inputtype == FORMAT_mac) && (outputtype ==FORMAT_eui64) ) {
-			action = ACTION_mac_to_eui64;
-		} else if ( (inputtype == FORMAT_iid_token) && (outputtype ==FORMAT_iid_token) ) {
-			action = ACTION_iid_token_to_privacy;
-		} else if ( inputtype == FORMAT_prefix_mac ) {
-			action = ACTION_prefix_mac_to_ipv6;
-			if ( outputtype == FORMAT_undefined ) {
-				outputtype = FORMAT_ipv6addr;
-			};
-		};
-		
-		if ( action != FORMAT_undefined ) {
-			if ((formatoptions & FORMATOPTION_quiet) == 0) {
-				fprintf(stderr, "No action type specified, try autodetection...");
-			};
-			for (i = 0; i < (int) (sizeof(ipv6calc_actionstrings) / sizeof(ipv6calc_actionstrings[0])); i++) {
-				if (action == ipv6calc_actionstrings[i].number) {
-					if ((formatoptions & FORMATOPTION_quiet) == 0) {
-						fprintf(stderr, "found type: %s\n", ipv6calc_actionstrings[i].token);
-					};
-					break;
-				};
-			};
-		} else {
-			/*
-			if ((formatoptions & FORMATOPTION_quiet) == 0) {
-				fprintf(stderr, "no result!\n");
-			};
-			*/
-		};
-	};
-
 	/***** input type handling *****/
 	if (ipv6calc_debug != 0) {
 		fprintf(stderr, "%s: Start of input type handling\n", DEBUG_function_name);
@@ -951,18 +919,52 @@ PIPE_input:
 	};
 
 	/* auto set of output type*/
-	if (inputtype == FORMAT_revnibbles_int || inputtype == FORMAT_revnibbles_arpa) {
+	if (inputtype == FORMAT_revnibbles_int || inputtype == FORMAT_revnibbles_arpa || inputtype == FORMAT_ipv6literal) {
 		if ( outputtype == FORMAT_undefined ) {
 			outputtype = FORMAT_ipv6addr;
 		};
 	};
 
+	/***** automatic action handling *****/
+	if (action == ACTION_undefined) {
+		if ( (inputtype == FORMAT_mac && (input_is_pipe == 0 || inputtype_given == 1)) && (outputtype == FORMAT_eui64 && outputtype_given == 1) ) {
+			action = ACTION_mac_to_eui64;
+		} else if ( (inputtype == FORMAT_iid_token && (input_is_pipe == 0 || inputtype_given == 1)) && (outputtype == FORMAT_iid_token && outputtype_given == 1) ) {
+			action = ACTION_iid_token_to_privacy;
+		} else if ( inputtype == FORMAT_prefix_mac && (input_is_pipe == 0 || inputtype_given == 1)) {
+			action = ACTION_prefix_mac_to_ipv6;
+			if ( outputtype == FORMAT_undefined ) {
+				outputtype = FORMAT_ipv6addr;
+			};
+		};
+	};
+
+	if (input_is_pipe == 0 && action_given == 0) {
+		if ( action != ACTION_undefined ) {
+			if ((formatoptions & FORMATOPTION_quiet) == 0) {
+				fprintf(stderr, "No action type specified, try autodetection...");
+			};
+			for (i = 0; i < (int) (sizeof(ipv6calc_actionstrings) / sizeof(ipv6calc_actionstrings[0])); i++) {
+				if (action == ipv6calc_actionstrings[i].number) {
+					if ((formatoptions & FORMATOPTION_quiet) == 0) {
+						fprintf(stderr, "found type: %s\n", ipv6calc_actionstrings[i].token);
+					};
+					break;
+				};
+			};
+		};
+	};
+
 	/* check formatoptions for validity */
+	if (ipv6calc_debug != 0) {
+		fprintf(stderr, "%s: check format option of output type: 0x%08lx\n", DEBUG_function_name, (unsigned long) outputtype);
+	};
+		
 	for (i = 0; i < (int) (sizeof(ipv6calc_outputformatoptionmap) / sizeof(ipv6calc_outputformatoptionmap[0])); i++) {
 		if (outputtype != ipv6calc_outputformatoptionmap[i][0]) {
 			continue;
 		};
-		
+
 		if ( (ipv6calc_outputformatoptionmap[i][1] & (formatoptions & ~ FORMATOPTION_quiet) ) == (formatoptions & ~ FORMATOPTION_quiet ) ) {
 			/* all options valid */
 			break;
@@ -987,11 +989,12 @@ PIPE_input:
 	retval = -1; /* default */
 
 	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Process input (inputtype:%lx, count=%d)\n", DEBUG_function_name, (unsigned long) inputtype, inputc);
+		fprintf(stderr, "%s: Process input (inputtype: 0x%08lx, count=%d)\n", DEBUG_function_name, (unsigned long) inputtype, inputc);
 	};
 
 	switch (inputtype) {
 		case FORMAT_ipv6addr:
+		case FORMAT_ipv6literal:
 		case FORMAT_ipv4addr:
 		case FORMAT_ipv4hex:
 		case FORMAT_ipv4revhex:
@@ -1021,6 +1024,11 @@ PIPE_input:
 			argc--;
 			break;
 
+		case FORMAT_ipv6literal:
+			retval = addrliteral_to_ipv6addrstruct(input1, resultstring, &ipv6addr);
+			argc--;
+			break;
+
 		case FORMAT_ipv4addr:
 			retval = addr_to_ipv4addrstruct(input1, resultstring, &ipv4addr);
 			argc--;
@@ -1278,7 +1286,7 @@ PIPE_input:
 	snprintf(resultstring, sizeof(resultstring) - 1, "%s", "");
 
 	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Process action (action:%lx)\n", DEBUG_function_name, (unsigned long) action);
+		fprintf(stderr, "%s: Process action (action: 0x%08lx)\n", DEBUG_function_name, (unsigned long) action);
 	};
 	
 	switch (action) {
@@ -1441,7 +1449,7 @@ PIPE_input:
 
 	/***** output type *****/
 	if (ipv6calc_debug != 0) {
-		fprintf(stderr, "%s: Process output (outputtype:%lx)\n", DEBUG_function_name, (unsigned long) outputtype);
+		fprintf(stderr, "%s: Process output (outputtype: 0x%08lx)\n", DEBUG_function_name, (unsigned long) outputtype);
 	};
 	
 	/* catch showinfo */	
@@ -1542,6 +1550,17 @@ PIPE_input:
 				retval = librfc1884_ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, formatoptions);
 			};
 			break;
+
+		case FORMAT_ipv6literal:
+			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_ipv6literal\n", DEBUG_function_name); }
+			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
+			if ((formatoptions & (FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed)) != 0) {
+				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions | FORMATOPTION_literal);
+			} else {
+				retval = librfc1884_ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, formatoptions | FORMATOPTION_literal);
+			};
+			break;
+			
 			
 		case FORMAT_ipv4addr:
 			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_ipv4addr\n", DEBUG_function_name); }
@@ -1551,7 +1570,9 @@ PIPE_input:
 			
 		case FORMAT_eui64:
 			if (ipv6calc_debug != 0) { fprintf(stderr, "%s: Start of output handling for FORMAT_eui64\n", DEBUG_function_name); }
-			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
+			if (action != ACTION_mac_to_eui64) { fprintf(stderr, "Specify proper action or input for output format: eui64\n"); exit(EXIT_FAILURE); };
+			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
+			if (ipv6addr.prefixlength != 64) { fprintf(stderr, "No valid EUI-64 identifier given!\n"); exit(EXIT_FAILURE); };
 			formatoptions |= FORMATOPTION_printsuffix;
 			retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions);
 			break;
@@ -1578,7 +1599,7 @@ PIPE_input:
 
 
 		default:
-			fprintf(stderr, " Outputtype isn't implemented: %lx\n", (unsigned long) outputtype);
+			fprintf(stderr, " Outputtype isn't implemented: %8lx\n", (unsigned long) outputtype);
 			exit(EXIT_FAILURE);
 	};
 
