@@ -2,7 +2,7 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc.sh
-# Version    : $Id: test_ipv6calc.sh,v 1.24 2011/09/16 19:52:05 peter Exp $
+# Version    : $Id: test_ipv6calc.sh,v 1.30 2012/01/10 20:50:16 peter Exp $
 # Copyright  : 2001-2011 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
@@ -12,6 +12,9 @@ if [ ! -x ./ipv6calc ]; then
 	exit 1
 fi
 
+# Test Scenarios for autodetection "good case"
+source ./test_scenarios.sh
+
 testscenarios() {
 # Command								Expected result (no space between "=" and result)
 cat <<END | grep -v '^#'
@@ -96,7 +99,11 @@ cat <<END | grep -v '^#'
 ## MAC to EUI-64
 --mac_to_eui64 00:50:BF:06:B4:F5					=250:bfff:fe06:b4f5
 --mac_to_eui64 00:0:F:6:4:5						=200:fff:fe06:405
---in mac --out eui64 00:0:F:6:4:5				=200:fff:fe06:405
+--in mac --out eui64 00:0:F:6:4:5					=200:fff:fe06:405
+--mac_to_eui64 0050BF-06B4F5						=250:bfff:fe06:b4f5
+--mac_to_eui64 0050BF06B4F5						=250:bfff:fe06:b4f5
+## MAC to EUI-64 (autodetect mode, not supported in pipe mode)
+NOPIPETEST--out eui64 00:0:F:6:4:5					=200:fff:fe06:405
 ## Interface identifier privacy conversion
 --eui64_to_privacy 0123:4567:89ab:cdef 0123456789abcdef			=4662:bdea:8654:776d 486072ff7074945e
 --in iid+token --out iid+token 0123:4567:89ab:cdef 0123456789abcdef			=4662:bdea:8654:776d 486072ff7074945e
@@ -137,52 +144,20 @@ cat <<END | grep -v '^#'
 --in ipv6addr --out ipv6addr 2001:DB8:0:0:1:0:0:1		 	=2001:db8::1:0:0:1
 # 6rd
 --action 6rd_local_prefix --6rd_prefix 2607:fedc:ff40::/43 --6rd_relay_prefix 6.230.0.0/15 6.231.32.33	=2607:fedc:ff52:210::/60
+# IPv6 literal
+--in ipv6literal fe80--1.IPV6-LITERAL.NET				=fe80::1
+--in ipv6literal fe80--1.IPV6-liTERal.NET				=fe80::1
+--in ipv6literal fe80--218-8bff-fe17-a226s4.ipv6-literal.net		=fe80::218:8bff:fe17:a226%4
+--out ipv6literal -u --in ipv6addr 2001:db8::1				=2001-DB8--1.IPV6-LITERAL.NET
+--out ipv6literal -U --in ipv6addr 2001:db8::1				=2001-db8-0-0-0-0-0-1.ipv6-literal.net
+--out ipv6literal -F --in ipv6addr 2001:db8::1				=2001-0db8-0000-0000-0000-0000-0000-0001.ipv6-literal.net
+--out ipv6literal --in ipv6addr fe80::1%0				=fe80--1s0.ipv6-literal.net
+--out ipv6literal -F --in ipv6addr fe80::1%0				=fe80-0000-0000-0000-0000-0000-0000-0001s0.ipv6-literal.net
+--out ipv6addr -U --in ipv6addr fe80::1%eth0				=fe80:0:0:0:0:0:0:1%eth0
+--out ipv6addr -F --in ipv6addr fe80::1%eth0				=fe80:0000:0000:0000:0000:0000:0000:0001%eth0
 END
 }
 
-# Test Scenarios for autodetection "good case"
-testscenarios_auto_good() {
-cat <<END | grep -v '^#'
-3ffe:831f:ce49:7601:8000:efff:af4a:86BF						ipv6addr
-1.2.3.4										ipv4addr
-1.2.3.4/0									ipv4addr
-1.2.3.4/32									ipv4addr
-01:23:45:67:89:01								mac
-2002:102:304::1/0								ipv6addr
-2002:102:304::1/128								ipv6addr
-\\\\[x3FFEFFFF000000000000000000000001/64].IP6.ARPA.				bitstring
-1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.int.	revnibbles.int
-1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.arpa.	revnibbles.arpa
-0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.arpa.		revnibbles.int
-12345678									ipv4hex
-4)+k&C#VzJ4br>0wv%Yp								base85
-# RFC 5952 2.x
-2001:db8:0:0:1:0:0:1								ipv6addr
-2001:0db8:0:0:1:0:0:1								ipv6addr
-2001:db8::1:0:0:1								ipv6addr
-2001:db8::0:1:0:0:1								ipv6addr
-2001:0db8::1:0:0:1								ipv6addr
-2001:db8:0:0:1::1								ipv6addr
-2001:db8:0000:0:1::1								ipv6addr
-2001:DB8:0:0:1::1								ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:eeee:0001						ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:eeee:001						ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:eeee:01						ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:eeee:1						ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd::1							ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:0:1						ipv6addr
-2001:db8:0:0:0::1								ipv6addr
-2001:db8:0:0::1									ipv6addr
-2001:db8:0::1									ipv6addr
-2001:db8::1									ipv6addr
-2001:db8::aaaa:0:0:1								ipv6addr
-2001:db8:0:0:aaaa::1								ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:eeee:aaaa						ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:eeee:AAAA						ipv6addr
-2001:db8:aaaa:bbbb:cccc:dddd:eeee:AaAa						ipv6addr
-64:ff9b::192.0.2.33								ipv6addr
-END
-}
 
 # Test Scenarios for autodetection "bad case"
 testscenarios_auto_bad() {
@@ -198,6 +173,7 @@ cat <<END | grep -v '^#'
 1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.arpa.arpa.	revnibbles.arpa
 0.0.0.0.01.0.0.0.0.0.0.0.0.1.0.1.f.0.0.1.0.f.f.f.f.e.f.f.3.ip6.arpa.		revnibbles.arpa
 123456789									ipv4hex
+fe80---1.IPV6-LITERAL.NET							ipv6literal
 END
 }
 
@@ -212,9 +188,28 @@ END
 
 #set -x
 ## main ##
+echo "Run 'ipv6calc' basic tests..."
+
+echo "Test './ipv6calc -v'"
+output="`./ipv6calc -v`"
+retval=$?
+if [ $retval -ne 0 ]; then
+	echo "Error executing: ipv6calc -v: $output"
+	exit 1
+fi
+
+echo "Test './ipv6calc -v -v'"
+output="`./ipv6calc -v -v`"
+retval=$?
+if [ $retval -ne 0 ]; then
+	echo "Error executing: ipv6calc -v -v: $output"
+	exit 1
+fi
+
+
 echo "Run 'ipv6calc' function tests..."
 
-testscenarios | while read line; do
+testscenarios | sed 's/NOPIPETEST//' | while read line; do
 	if [ -z "$line" ]; then
 		# end
 		continue
@@ -353,7 +348,7 @@ done || exit 1
 
 echo "Run 'ipv6calc' pipe tests (2)"
 # reuse original test cases
-testscenarios | while read line; do
+testscenarios | grep -v "^NOPIPETEST" | while read line; do
 	# extract result
 	command="`echo "$line" | awk -F= '{ print $1 }' | sed 's/ $//g'`"
 	result="`echo "$line" | awk -F= '{ print $2 }'`"
