@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6addr.h
- * Version    : $Id: libipv6addr.h,v 1.31 2011/09/16 18:05:13 peter Exp $
+ * Version    : $Id: libipv6addr.h,v 1.33 2011/11/27 15:44:41 peter Exp $
  * Copyright  : 2001-2011 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -28,6 +28,8 @@ typedef struct {
 	uint8_t bit_end;		/* end of bit */
 	int flag_startend_use;		/* =1 start or end of bit in use */
 	int flag_valid;			/* address structure filled */
+	char scopeid[NI_MAXHOST];	/* scope ID value */
+	int flag_scopeid;		/* =1: scope ID value set */
 } ipv6calc_ipv6addr;
 
 /* IPv6 address assignment structure */
@@ -169,7 +171,7 @@ extern int ipv6addr_getregistry(const ipv6calc_ipv6addr *ipv6addrp);
 extern int libipv6addr_get_registry_string(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring);
 
 extern int  addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_ipv6addr *ipv6addrp);
-
+extern int  addrliteral_to_ipv6addrstruct(const char *addrstring, char *resultstring, ipv6calc_ipv6addr *ipv6addrp);
 
 extern int  libipv6addr_ipv6addrstruct_to_uncompaddr(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions);
 extern int  libipv6addr_to_octal(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions);
